@@ -12,9 +12,11 @@ from subprocess import PIPE, Popen
 
 INOUTPREFIX = 'inout:'
 comments = re.compile(r'<!--.*?-->', re.DOTALL)
-scripttag = re.compile(r'(<script[^>]*src="([^"]*)"(?! class="jspack).*?(?:</script>|/>))')
 usestrict = re.compile(r'("use strict";)')
 scripttemplate = r'(<script[^>]*src="(%s[^"]*)"(?! class="jspack).*?(?:</script>|/>))'
+scripttag = re.compile(scripttemplate % '')
+linktemplate = r'(<link[^>]*href="(%s[^"]*)"(?! class="jspack).*?(?:</link>|/>))'
+linktag = re.compile(linktemplate % '')
 # Filled using scripttemplate and option include in main()
 customscripttag = None
 
@@ -117,7 +119,12 @@ def process_cfg(cfgpath, options):
                 if not isabs(html):
                     html = join(root, html)
                 # TODO: Improve. Now we are wrinting the file len(sections) times
-                replace(html, section, cfiles)
+                if section.endswith('.css'):
+                    replace_css(html, section, cfiles)
+                elif section.endswith('.js'):
+                    replace_js(html, section, cfiles)
+                else:
+                    loggin.warn('Not replacing in seccion "%s"' % section)
         if options.pack:
             minimizer = False
             if config.has_option(section, 'minimizer'):
@@ -134,7 +141,7 @@ def process_cfg(cfgpath, options):
             logging.info("Writing to %s (%d KB)" % (section, int(len(merged) / 1024)))
 
 
-def replace(path, jsminimized, files):
+def replace_js(path, jsminimized, files):
 
     with open(path, 'r') as htmlfile:
         data = htmlfile.read()
@@ -150,23 +157,50 @@ def replace(path, jsminimized, files):
         htmlfile.write(data)
 
 
+def replace_css(path, jsminimized, files):
+
+    with open(path, 'r') as htmlfile:
+        data = htmlfile.read()
+    for f in files:
+        # TODO: Fails with js/abc.js followed by js/abc.js.more.js
+        tosearch = linktemplate % f
+        if not re.search(r'<!-- \S* includes: ' + tosearch, data):
+            data = re.sub(tosearch, r'<!-- %s includes: \1 -->' % jsminimized, data)
+    newtag = '<link rel="stylesheet" type="text/css" href="%s" class="jspack"/>' % jsminimized
+    if not newtag in data:
+        data = data.replace('</head>', '%s\n</head>' % newtag)
+    with open(path, 'w') as htmlfile:
+        htmlfile.write(data)
+
+
 def process_html(path, options):
     logging.debug('Procesing... %s' % path)
     head, tail = split(path)
     base = splitext(tail)[0]
-    section = base + '-minimized.js'
     with open(path, 'r') as htmlfile:
         data = htmlfile.read()
         data = comments.sub('', data)
         js = [src for tag, src in customscripttag.findall(data)]
+        css = [href for tag, href in linktag.findall(data)]
+    config = ConfigParser()
     if js:
-        config = ConfigParser()
+        section = base + '-minimized.js'
         config.add_section(section)
         if head:
             config.set(section, 'root', head)
         config.set(section, 'html', path)
         config.set(section, 'minimizer', 'jsmin')
         config.set(section, 'files', ' \n  '.join(js))
+    if css:
+        section = base + '-minimized.css'
+        config.add_section(section)
+        if head:
+            config.set(section, 'root', head)
+        config.set(section, 'html', path)
+        config.set(section, 'minimizer', 'none')
+        config.set(section, 'files', ' \n  '.join(css))
+
+    if config.sections():
         if options.write_config:
             cfgpath = join(head, base + '.jspack.cfg')
             if isfile(cfgpath) and not options.overwrite_config:
